@@ -28,14 +28,13 @@ except:
 def diropenbox(msg=None, title=None, default=None):
     """
     A dialog to get a directory name.
-    Note that the msg argument, if specified, is ignored.
 
     Returns the name of a directory, or None if user chose to cancel.
 
     If the "default" argument specifies a directory name, and that
     directory exists, then the dialog box will start with that directory.
 
-    :param str msg: the msg to be displayed
+    :param str msg: used in the window title on some platforms
     :param str title: the window title
     :param str default: starting directory when dialog opens
     :return: Normalized path selected by user
@@ -43,8 +42,12 @@ def diropenbox(msg=None, title=None, default=None):
     title = ut.getFileDialogTitle(msg, title)
     localRoot = tk.Tk()
     localRoot.withdraw()
+    localRoot.lift()
+    localRoot.attributes('-topmost', 1)
+    localRoot.attributes('-topmost', 0)
     if not default:
         default = None
+    localRoot.update() #fix ghost window issue #119 on mac.
     f = ut.tk_FileDialog.askdirectory(
         parent=localRoot, title=title, initialdir=default, initialfile=None
     )
@@ -56,3 +59,8 @@ def diropenbox(msg=None, title=None, default=None):
 
 if __name__ == '__main__':
     print("Hello from base_boxes")
+    my_dir = diropenbox(
+        "You really should open a file",
+        title="Open a dir",
+        default='./')
+    print("directory {} selected.".format(my_dir))
