@@ -36,9 +36,22 @@ def filesavebox(msg=None, title=None, default="", filetypes=None):
     A file to get the name of a file to save.
     Returns the name of a file, or None if user chose to cancel.
 
-    The "default" argument should contain a filename (i.e. the
-    current name of the file to be saved).  It may also be empty,
-    or contain a filemask that includes wildcards.
+    **About the "default" argument**
+
+    The ``default`` argument specifies the path and "glob pattern" for file
+    names. The "\\*" value, for example, sets the open file dialog to the
+    current working directory and showing all files.
+
+    For another example, setting the ``default`` argument to ``"C:/myjunk/*.py"``
+    sets the open file dialog to the C:\\myjunk folder and showing only files
+    that have the .py file extension. This glob pattern at the end of the
+    ``default`` argument is required: passing ``"C:/myjunk"`` would not set the
+    open file dialog to the C:\\myjunk folder, but rather to the C:\\ folder
+    and "myjunk" as the initial filename.
+
+    Note that on Windows, ``fileopenbox()`` automatically changes the path
+    separator to the Windows path separator (backslash).
+
 
     The "filetypes" argument works like the "filetypes" argument to
     fileopenbox.
@@ -46,7 +59,7 @@ def filesavebox(msg=None, title=None, default="", filetypes=None):
     :param str msg: the msg to be displayed.
     :param str title: the window title
     :param str default: default filename to return
-    :param object filetypes: filemasks that a user can choose, e.g. " \*.txt"
+    :param object filetypes: filemasks that a user can choose, e.g. " \\*.txt"
     :return: the name of a file, or None if user chose to cancel
     """
 
